@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2018 NVIDIA Corporation.  All rights reserved.
+ * Copyright 2010-2019 NVIDIA Corporation.  All rights reserved.
  *
  * NOTICE TO LICENSEE:
  *
@@ -64,7 +64,7 @@ extern "C" {
 
 #if defined(__GNUC__) && defined(CUPTI_LIB)
     #pragma GCC visibility push(default)
-#endif    
+#endif
 
 /**
  * \defgroup CUPTI_RESULT_API CUPTI Result Codes
@@ -247,9 +247,25 @@ typedef enum {
      * Old profiling api's are not supported with new profiling api's
      */
     CUPTI_ERROR_OLD_PROFILER_API_INITIALIZED             = 36,
+    /**
+     * Missing definition of the OpenACC API routine in the linked OpenACC library.
+     *
+     * One possible reason is that OpenACC library is linked statically in the
+     * user application, which might not have the definition of all the OpenACC
+     * API routines needed for the OpenACC profiling, as compiler might ignore
+     * definitions for the functions not used in the application. This issue
+     * can be mitigated by linking the OpenACC library dynamically.
+     */
+    CUPTI_ERROR_OPENACC_UNDEFINED_ROUTINE                = 37,
     /**
      * An unknown internal error has occurred.
      */
+    /**
+     * Legacy CUPTI Profiling is not supported on devices with Compute Capability
+     * 7.5 or higher (Turing+). Using this error to specify this case and differentiate
+     * it from other errors.
+     */
+    CUPTI_ERROR_LEGACY_PROFILER_NOT_SUPPORTED            = 38,
     CUPTI_ERROR_UNKNOWN                                  = 999,
     CUPTI_ERROR_FORCE_INT                                = 0x7fffffff
 } CUptiResult;
