@@ -1235,6 +1235,13 @@ typedef struct cuOccupancyMaxPotentialBlockSizeWithFlags_params_st {
     unsigned int flags;
 } cuOccupancyMaxPotentialBlockSizeWithFlags_params;
 
+typedef struct cuOccupancyAvailableDynamicSMemPerBlock_params_st {
+    size_t *dynamicSmemSize;
+    CUfunction func;
+    int numBlocks;
+    int blockSize;
+} cuOccupancyAvailableDynamicSMemPerBlock_params;
+
 typedef struct cuTexRefSetArray_params_st {
     CUtexref hTexRef;
     CUarray hArray;
@@ -1497,6 +1504,12 @@ typedef struct cuGetExportTable_params_st {
     const CUuuid *pExportTableId;
 } cuGetExportTable_params;
 
+typedef struct cuDeviceGetNvSciSyncAttributes_params_st {
+    void *nvSciSyncAttrList;
+    CUdevice dev;
+    int flags;
+} cuDeviceGetNvSciSyncAttributes_params;
+
 typedef struct cuMemHostRegister_params_st {
     void *p;
     size_t bytesize;
