@@ -1506,35 +1506,6 @@ typedef struct cudaStreamGetCaptureInfo_v10010_params_st {
 } cudaStreamGetCaptureInfo_v10010_params;
 
 // Parameter trace structures for removed functions 
-typedef struct cudaStreamDestroy_v3020_params_st {
-    cudaStream_t stream;
-} cudaStreamDestroy_v3020_params;
 
-typedef struct cudaOccupancyMaxActiveBlocksPerMultiprocessor_v6000_params_st {
-    int *numBlocks;
-    const void *func;
-    size_t numDynamicSmemBytes;
-} cudaOccupancyMaxActiveBlocksPerMultiprocessor_v6000_params;
-
-typedef struct cudaConfigureCall_v3020_params_st {
-    dim3 gridDim;
-    dim3 blockDim;
-    size_t sharedMem;
-    cudaStream_t stream;
-} cudaConfigureCall_v3020_params;
-
-typedef struct cudaSetupArgument_v3020_params_st {
-    const void *arg;
-    size_t size;
-    size_t offset;
-} cudaSetupArgument_v3020_params;
-
-typedef struct cudaLaunch_v3020_params_st {
-    const void *func;
-} cudaLaunch_v3020_params;
-
-typedef struct cudaLaunch_ptsz_v7000_params_st {
-    const void *func;
-} cudaLaunch_ptsz_v7000_params;
 
 // End of parameter trace structures
