@@ -61,6 +61,9 @@
 
 #define CUDA_NUM_CUDART_FRAME_ENTRIES 3
 
+struct blockvector *
+cuda_alloc_blockvector (struct symtab *symtab, int nblocks);
+
 static struct {
   struct objfile *objfile;
 } cuda_cudart_symbols;
@@ -1603,15 +1606,20 @@ cuda_create_symbol (struct objfile *objfile, const char *name, CORE_ADDR addr, s
 /* Symtab initialization helper routine:
  * Allocates blockvector as well as global and static blocks inside symtab 
  */
-static void
-cuda_alloc_blockvector (struct symtab *symtab)
+struct blockvector *
+cuda_alloc_blockvector (struct symtab *symtab, int nblocks)
 {
+  int i;
   struct obstack *obstack = &(SYMTAB_OBJFILE (symtab)->objfile_obstack);
   struct blockvector *bv;
   struct block *bl;
 
-  bv = (struct blockvector *) obstack_alloc (obstack, sizeof(struct blockvector) + sizeof(struct block *));
-  BLOCKVECTOR_NBLOCKS (bv) = 1;
+  /* At least enough room for the global and static blocks */
+  gdb_assert (nblocks >= 2);
+
+  bv = (struct blockvector *) obstack_alloc (obstack, sizeof(struct blockvector) + sizeof(struct block *) * (nblocks - 1));
+  BLOCKVECTOR_NBLOCKS (bv) = nblocks;
+  BLOCKVECTOR_MAP (bv) = 0;
 
   /* Allocate global block */
   bl = allocate_global_block (obstack);
@@ -1625,7 +1633,10 @@ cuda_alloc_blockvector (struct symtab *symtab)
   BLOCKVECTOR_BLOCK (bv, STATIC_BLOCK) = bl;
   set_block_compunit_symtab (bl, SYMTAB_COMPUNIT (symtab));
 
-  SYMTAB_BLOCKVECTOR (symtab) = bv;
+  /* Zero the rest */
+  for (i = 2; i < nblocks; ++i)
+    BLOCKVECTOR_BLOCK (bv, i) = NULL;
+  return bv;
 }
 
 /* Allocate virtual objfile and construct the following symbols inside it:
@@ -1642,7 +1653,6 @@ cuda_create_builtins_objfile (void)
   struct type *int32_type = NULL;
   struct type *dim3_type = NULL;
   struct symtab *symtab = NULL;
-  struct blockvector *bv = NULL;
   struct cleanup *cleanups = NULL;
 
   /* Initialized things since we are going to start assembling a new
@@ -1670,7 +1680,8 @@ cuda_create_builtins_objfile (void)
 
   symtab->language = language_c;
 
-  cuda_alloc_blockvector (symtab);
+  /* Allocate 2 blocks: GLOBAL and STATIC */
+  COMPUNIT_BLOCKVECTOR (objfile->compunit_symtabs) = cuda_alloc_blockvector (symtab, 2);
 
   cuda_create_symbol (objfile, "threadIdx", CUDBG_THREADIDX_OFFSET, dim3_type);
   cuda_create_symbol (objfile, "blockIdx", CUDBG_BLOCKIDX_OFFSET, dim3_type);
