@@ -80,7 +80,7 @@ require_partial_symbols (struct objfile *objfile, int verbose)
     {
       objfile->flags |= OBJF_PSYMTABS_READ;
 
-      if (objfile->sf->sym_read_psymbols)
+      if (objfile->sf && objfile->sf->sym_read_psymbols)
 	{
 	  if (verbose)
 	    {
@@ -1960,6 +1960,9 @@ dump_psymtab_addrmap (struct objfile *objfile, struct partial_symtab *psymtab,
 {
   struct dump_psymtab_addrmap_data addrmap_dump_data;
 
+  if (!objfile->psymtabs_addrmap)
+      return;
+
   if (psymtab == NULL
       || psymtab->psymtabs_addrmap_supported)
     {
