@@ -113,7 +113,7 @@ typedef struct cublasLtMatmulPreferenceStruct *cublasLtMatmulPreference_t;
  *
  * General order of tile IDs is sort by size first by first dimension next.
  */
-enum cublasLtMatmulTile_t {
+typedef enum {
     CUBLASLT_MATMUL_TILE_UNDEFINED = 0,
     CUBLASLT_MATMUL_TILE_8x8       = 1,
     CUBLASLT_MATMUL_TILE_8x16      = 2,
@@ -141,10 +141,10 @@ enum cublasLtMatmulTile_t {
     CUBLASLT_MATMUL_TILE_256x128   = 24,
     CUBLASLT_MATMUL_TILE_512x64    = 25,
     CUBLASLT_MATMUL_TILE_END
-};
+} cublasLtMatmulTile_t;
 
 /** Pointer mode to use for alpha/beta */
-enum cublasLtPointerMode_t {
+typedef enum {
     /** matches CUBLAS_POINTER_MODE_HOST, pointer targets a single value host memory */
     CUBLASLT_POINTER_MODE_HOST = CUBLAS_POINTER_MODE_HOST,
     /** matches CUBLAS_POINTER_MODE_DEVICE, pointer targets a single value device memory */
@@ -153,10 +153,10 @@ enum cublasLtPointerMode_t {
     CUBLASLT_POINTER_MODE_DEVICE_VECTOR = 2,
     /** alpha pointer targets an array in device memory, beta is zero */
     CUBLASLT_POINTER_MODE_ALPHA_DEVICE_VECTOR_BETA_ZERO = 3,
-};
+} cublasLtPointerMode_t;
 
 /** Mask to define and query pointer mode capability */
-enum cublasLtPointerModeMask_t {
+typedef enum {
     /** see CUBLASLT_POINTER_MODE_HOST */
     CUBLASLT_POINTER_MODE_MASK_HOST = 1,
     /** see CUBLASLT_POINTER_MODE_DEVICE */
@@ -165,7 +165,7 @@ enum cublasLtPointerModeMask_t {
     CUBLASLT_POINTER_MODE_MASK_DEVICE_VECTOR = 4,
     /** see CUBLASLT_POINTER_MODE_ALPHA_DEVICE_VECTOR_BETA_ZERO */
     CUBLASLT_POINTER_MODE_MASK_ALPHA_DEVICE_VECTOR_BETA_ZERO = 8,
-};
+} cublasLtPointerModeMask_t;
 
 /** Execute matrix multiplication (D = alpha * op(A) * op(B) + beta * C).
  *
