@@ -70,6 +70,13 @@
 extern "C" {
 #endif /* __cplusplus */
 
+#define CURAND_VER_MAJOR 10
+#define CURAND_VER_MINOR 1
+#define CURAND_VER_PATCH 1
+#define CURAND_VER_BUILD 243
+#define CURAND_VERSION (CURAND_VER_MAJOR * 1000 + \
+                        CURAND_VER_MINOR *  100 + \
+                        CURAND_VER_PATCH)
 /* CURAND Host API datatypes */
 
 /**  
@@ -213,7 +220,7 @@ typedef struct curandDiscreteDistribution_st *curandDiscreteDistribution_t;
  * CURAND METHOD
  */
 /** \cond UNHIDE_ENUMS */
-enum curandMethod {
+typedef enum curandMethod {
     CURAND_CHOOSE_BEST = 0, // choose best depends on args
     CURAND_ITR = 1,
     CURAND_KNUTH = 2,
@@ -228,9 +235,7 @@ enum curandMethod {
     CURAND_3RD = 11,
     CURAND_DEFINITION = 12,
     CURAND_POISSON = 13
-};
-
-typedef enum curandMethod curandMethod_t;
+} curandMethod_t;
 /** \endcond */
 
 /**
