@@ -59,14 +59,6 @@
 #include "cublas_v2.h"
 #include "cusolver_common.h"
 
-#if defined(CUSOLVER_ILP64)
-typedef long long int cusolver_int_t;  // MKL uses long long int, not int64_t
-#else
-typedef int cusolver_int_t;
-#endif
-
-
-
 
 #if defined(__cplusplus)
 extern "C" {
@@ -1050,6 +1042,192 @@ cusolverStatus_t CUSOLVERAPI cusolverDnZsytrf(
     int lwork,
     int *info );
 
+/* Symmetric indefinite solve (SYTRS) */
+cusolverStatus_t CUSOLVERAPI cusolverDnSsytrs_bufferSize(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        int nrhs,
+        const float *A,
+        int lda,
+        const int *ipiv,
+        float *B,
+        int ldb,
+        int *lwork);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsytrs_bufferSize(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        int nrhs,
+        const double *A,
+        int lda,
+        const int *ipiv,
+        double *B,
+        int ldb,
+        int *lwork);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCsytrs_bufferSize(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        int nrhs,
+        const cuComplex *A,
+        int lda,
+        const int *ipiv,
+        cuComplex *B,
+        int ldb,
+        int *lwork);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZsytrs_bufferSize(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        int nrhs,
+        const cuDoubleComplex *A,
+        int lda,
+        const int *ipiv,
+        cuDoubleComplex *B,
+        int ldb,
+        int *lwork);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSsytrs(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        int nrhs,
+        const float *A,
+        int lda,
+        const int *ipiv,
+        float *B,
+        int ldb,
+        float *work,
+        int lwork,
+        int *info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsytrs(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        int nrhs,
+        const double *A,
+        int lda,
+        const int *ipiv,
+        double *B,
+        int ldb,
+        double *work,
+        int lwork,
+        int *info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCsytrs(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        int nrhs,
+        const cuComplex *A,
+        int lda,
+        const int *ipiv,
+        cuComplex *B,
+        int ldb,
+        cuComplex *work,
+        int lwork,
+        int *info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZsytrs(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        int nrhs,
+        const cuDoubleComplex *A,
+        int lda,
+        const int *ipiv,
+        cuDoubleComplex *B,
+        int ldb,
+        cuDoubleComplex *work,
+        int lwork,
+        int *info);
+
+/* Symmetric indefinite inversion (sytri) */
+cusolverStatus_t CUSOLVERAPI cusolverDnSsytri_bufferSize(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        float *A,
+        int lda,
+        const int *ipiv,
+        int *lwork);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsytri_bufferSize(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        double *A,
+        int lda,
+        const int *ipiv,
+        int *lwork);
+;
+cusolverStatus_t CUSOLVERAPI cusolverDnCsytri_bufferSize(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        cuComplex *A,
+        int lda,
+        const int *ipiv,
+        int *lwork);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZsytri_bufferSize(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        cuDoubleComplex *A,
+        int lda,
+        const int *ipiv,
+        int *lwork);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnSsytri(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        float *A,
+        int lda,
+        const int *ipiv,
+        float *work,
+        int lwork,
+        int *info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnDsytri(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        double *A,
+        int lda,
+        const int *ipiv,
+        double *work,
+        int lwork,
+        int *info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnCsytri(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        cuComplex *A,
+        int lda,
+        const int *ipiv,
+        cuComplex *work,
+        int lwork,
+        int *info);
+
+cusolverStatus_t CUSOLVERAPI cusolverDnZsytri(
+        cusolverDnHandle_t handle,
+        cublasFillMode_t uplo,
+        int n,
+        cuDoubleComplex *A,
+        int lda,
+        const int *ipiv,
+        cuDoubleComplex *work,
+        int lwork,
+        int *info);
+
 
 /* bidiagonal factorization */
 cusolverStatus_t CUSOLVERAPI cusolverDnSgebrd_bufferSize(
