@@ -1,50 +1,52 @@
- /* Copyright 2009-2019 NVIDIA Corporation.  All rights reserved. 
- // 
- // NOTICE TO LICENSEE: 
- // 
- // The source code and/or documentation ("Licensed Deliverables") are 
- // subject to NVIDIA intellectual property rights under U.S. and 
- // international Copyright laws. 
- // 
- // The Licensed Deliverables contained herein are PROPRIETARY and 
- // CONFIDENTIAL to NVIDIA and are being provided under the terms and 
- // conditions of a form of NVIDIA software license agreement by and 
- // between NVIDIA and Licensee ("License Agreement") or electronically 
- // accepted by Licensee.  Notwithstanding any terms or conditions to 
- // the contrary in the License Agreement, reproduction or disclosure 
- // of the Licensed Deliverables to any third party without the express 
- // written consent of NVIDIA is prohibited. 
- // 
- // NOTWITHSTANDING ANY TERMS OR CONDITIONS TO THE CONTRARY IN THE 
- // LICENSE AGREEMENT, NVIDIA MAKES NO REPRESENTATION ABOUT THE 
- // SUITABILITY OF THESE LICENSED DELIVERABLES FOR ANY PURPOSE.  THEY ARE 
- // PROVIDED "AS IS" WITHOUT EXPRESS OR IMPLIED WARRANTY OF ANY KIND. 
- // NVIDIA DISCLAIMS ALL WARRANTIES WITH REGARD TO THESE LICENSED 
- // DELIVERABLES, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY, 
- // NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE. 
- // NOTWITHSTANDING ANY TERMS OR CONDITIONS TO THE CONTRARY IN THE 
- // LICENSE AGREEMENT, IN NO EVENT SHALL NVIDIA BE LIABLE FOR ANY 
- // SPECIAL, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, OR ANY 
- // DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, 
- // WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS 
- // ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
- // OF THESE LICENSED DELIVERABLES. 
- // 
- // U.S. Government End Users.  These Licensed Deliverables are a 
- // "commercial item" as that term is defined at 48 C.F.R. 2.101 (OCT 
- // 1995), consisting of "commercial computer software" and "commercial 
- // computer software documentation" as such terms are used in 48 
- // C.F.R. 12.212 (SEPT 1995) and are provided to the U.S. Government 
- // only as a commercial end item.  Consistent with 48 C.F.R.12.212 and 
- // 48 C.F.R. 227.7202-1 through 227.7202-4 (JUNE 1995), all 
- // U.S. Government End Users acquire the Licensed Deliverables with 
- // only those rights set forth herein. 
- // 
- // Any use of the Licensed Deliverables in individual and commercial 
- // software must include, in the user documentation and internal 
- // comments to the code, the above Disclaimer and U.S. Government End 
- // Users Notice. 
-  */ 
+/*
+ * Copyright 2009-2019 NVIDIA Corporation.  All rights reserved.
+ *
+ * NOTICE TO LICENSEE:
+ *
+ * This source code and/or documentation ("Licensed Deliverables") are
+ * subject to NVIDIA intellectual property rights under U.S. and
+ * international Copyright laws.
+ *
+ * These Licensed Deliverables contained herein is PROPRIETARY and
+ * CONFIDENTIAL to NVIDIA and is being provided under the terms and
+ * conditions of a form of NVIDIA software license agreement by and
+ * between NVIDIA and Licensee ("License Agreement") or electronically
+ * accepted by Licensee.  Notwithstanding any terms or conditions to
+ * the contrary in the License Agreement, reproduction or disclosure
+ * of the Licensed Deliverables to any third party without the express
+ * written consent of NVIDIA is prohibited.
+ *
+ * NOTWITHSTANDING ANY TERMS OR CONDITIONS TO THE CONTRARY IN THE
+ * LICENSE AGREEMENT, NVIDIA MAKES NO REPRESENTATION ABOUT THE
+ * SUITABILITY OF THESE LICENSED DELIVERABLES FOR ANY PURPOSE.  IT IS
+ * PROVIDED "AS IS" WITHOUT EXPRESS OR IMPLIED WARRANTY OF ANY KIND.
+ * NVIDIA DISCLAIMS ALL WARRANTIES WITH REGARD TO THESE LICENSED
+ * DELIVERABLES, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY,
+ * NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE.
+ * NOTWITHSTANDING ANY TERMS OR CONDITIONS TO THE CONTRARY IN THE
+ * LICENSE AGREEMENT, IN NO EVENT SHALL NVIDIA BE LIABLE FOR ANY
+ * SPECIAL, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, OR ANY
+ * DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
+ * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
+ * OF THESE LICENSED DELIVERABLES.
+ *
+ * U.S. Government End Users.  These Licensed Deliverables are a
+ * "commercial item" as that term is defined at 48 C.F.R. 2.101 (OCT
+ * 1995), consisting of "commercial computer software" and "commercial
+ * computer software documentation" as such terms are used in 48
+ * C.F.R. 12.212 (SEPT 1995) and is provided to the U.S. Government
+ * only as a commercial end item.  Consistent with 48 C.F.R.12.212 and
+ * 48 C.F.R. 227.7202-1 through 227.7202-4 (JUNE 1995), all
+ * U.S. Government End Users acquire the Licensed Deliverables with
+ * only those rights set forth herein.
+ *
+ * Any use of the Licensed Deliverables in individual and commercial
+ * software must include, in the user documentation and internal
+ * comments to the code, the above Disclaimer and U.S. Government End
+ * Users Notice.
+ */
+
   
 #ifndef NV_JPEG_HEADER
 #define NV_JPEG_HEADER
@@ -66,9 +68,9 @@
 
 // nvjpeg version information
 #define NVJPEG_VER_MAJOR 10
-#define NVJPEG_VER_MINOR 2
+#define NVJPEG_VER_MINOR 3
 #define NVJPEG_VER_PATCH 0
-#define NVJPEG_VER_BUILD 0
+#define NVJPEG_VER_BUILD 243
 
 /* nvJPEG status enums, returned by nvJPEG API */
 typedef enum
@@ -147,6 +149,16 @@ typedef enum
     NVJPEG_BACKEND_GPU_HYBRID = 2,
 } nvjpegBackend_t;
 
+// Currently parseable JPEG encodings (SOF markers)
+typedef enum
+{
+    NVJPEG_ENCODING_UNKNOWN                                 = 0x0,
+
+    NVJPEG_ENCODING_BASELINE_DCT                            = 0xc0,
+    NVJPEG_ENCODING_PROGRESSIVE_DCT_HUFFMAN                 = 0xc2
+
+} nvjpegJpegEncoding_t;
+
 #define NVJPEG_FLAGS_DEFAULT 0
 
 // Output descriptor.
@@ -426,6 +438,11 @@ nvjpegStatus_t NVJPEGAPI nvjpegEncoderParamsSetQuality(
         const int quality,
         cudaStream_t stream);
 
+nvjpegStatus_t NVJPEGAPI nvjpegEncoderParamsSetEncoding(
+        nvjpegEncoderParams_t encoder_params,
+        nvjpegJpegEncoding_t etype,
+        cudaStream_t stream);
+
 nvjpegStatus_t NVJPEGAPI nvjpegEncoderParamsSetOptimizedHuffman(
         nvjpegEncoderParams_t encoder_params,
         const int optimized,
@@ -536,6 +553,10 @@ nvjpegStatus_t NVJPEGAPI nvjpegJpegStreamParse(
     int save_stream,
     nvjpegJpegStream_t jpeg_stream);
 
+nvjpegStatus_t NVJPEGAPI nvjpegJpegStreamGetJpegEncoding(
+    nvjpegJpegStream_t jpeg_stream,
+    nvjpegJpegEncoding_t* jpeg_encoding);
+
 nvjpegStatus_t NVJPEGAPI nvjpegJpegStreamGetFrameDimensions(
     nvjpegJpegStream_t jpeg_stream,
     unsigned int* width,
@@ -551,6 +572,9 @@ nvjpegStatus_t NVJPEGAPI nvjpegJpegStreamGetComponentDimensions(
     unsigned int* width,
     unsigned int* height);
 
+
+
+
 // if encoded is 1 color component then it assumes 4:0:0 (NVJPEG_CSS_GRAY, grayscale)
 // if encoded is 3 color components it tries to assign one of the known subsamplings
 //   based on the components subsampling infromation
@@ -643,6 +667,30 @@ nvjpegStatus_t NVJPEGAPI nvjpegDecodeJpegDevice(
     nvjpegImage_t *destination,
     cudaStream_t stream);
 
+///////////////////////////////////////////////////////////////////////////////////
+// JPEG Transcoding Functions //
+///////////////////////////////////////////////////////////////////////////////////
+
+// copies metadata (JFIF, APP, EXT, COM markers) from parsed stream
+nvjpegStatus_t nvjpegEncoderParamsCopyMetadata(
+	nvjpegEncoderState_t encoder_state,
+    nvjpegEncoderParams_t encode_params,
+    nvjpegJpegStream_t jpeg_stream,
+    cudaStream_t stream);
+
+// copies quantization tables from parsed stream
+nvjpegStatus_t nvjpegEncoderParamsCopyQuantizationTables(
+    nvjpegEncoderParams_t encode_params,
+    nvjpegJpegStream_t jpeg_stream,
+    cudaStream_t stream);
+
+// copies huffman tables from parsed stream. should require same scans structure
+nvjpegStatus_t nvjpegEncoderParamsCopyHuffmanTables(
+    nvjpegEncoderState_t encoder_state,
+    nvjpegEncoderParams_t encode_params,
+    nvjpegJpegStream_t jpeg_stream,
+    cudaStream_t stream);
+
 #if defined(__cplusplus)
   }
 #endif
